@@ -1,7 +1,10 @@
 
 /*
  *  agCgi.c
- *  $Id: agCgi.c,v 4.5 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: agCgi.c,v 4.11 2006/09/24 02:58:59 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:56:19 bkorb"
+ *  Last Committed:    $Date: 2006/09/24 02:58:59 $
  *
  *  This is a CGI wrapper for AutoGen.  It will take POST-method
  *  name-value pairs and emit AutoGen definitions to a spawned
@@ -9,7 +12,7 @@
  */
 
 /*
- *  AutoGen-cgi copyright 2001-2005 Bruce Korb
+ *  AutoGen-cgi copyright 2001-2006 Bruce Korb
  *
  *  AutoGen-cgi is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -29,7 +32,7 @@
  */
 
 typedef struct {
-    const char*  pzName;
+    char const*  pzName;
     char*        pzValue;
 } tNameMap;
 
@@ -73,7 +76,7 @@ typedef enum {
 #define pzCgiQuery  nameValueMap[ QUERY_STRING_IDX   ].pzValue
 #define pzCgiLength nameValueMap[ CONTENT_LENGTH_IDX ].pzValue
 
-static const char zOops[] =
+static char const zOops[] =
 "Content-type: text/plain\n\n"
 "AutoGen form processing error:\n";
 
@@ -97,15 +100,7 @@ loadCgi( void )
     pzOopsPrefix = zOops;
     {
         int tmpfd;
-        tCC* pz = getenv( "TEMP" );
-        if (pz == NULL) {
-            pz = getenv( "TMP" );
-            if (pz == NULL)
-                pz = "/tmp";
-        }
-
-        pzTmpStderr = aprf( "%s/agtmp.XXXXXX", pz );
-        TAGMEM( pzTmpStderr, "temp stderr file template" );
+        pzTmpStderr = mkstempPat();
         tmpfd = mkstemp( pzTmpStderr );
         if (tmpfd < 0)
             AG_ABEND(aprf("failed to create temp file from `%s'", pzTmpStderr));
@@ -119,7 +114,7 @@ loadCgi( void )
      */
     {
         tNameMap* pNM = nameValueMap;
-        tNameIdx  ix  = 0;
+        tNameIdx  ix  = (tNameIdx)0;
 
         do  {
             static char zNUL[1] = "";
@@ -133,8 +128,8 @@ loadCgi( void )
     memset( (void*)pBaseCtx, 0, sizeof( tScanCtx ));
 
     {
-        int   textLen = atoi( pzCgiLength );
-        char* pzText;
+        size_t textLen = strtoul( pzCgiLength, NULL, 0 );
+        char*  pzText;
 
         if (strcasecmp( pzCgiMethod, "POST" ) == 0) {
             if (textLen == 0)
@@ -147,13 +142,13 @@ loadCgi( void )
 
             pzText[ textLen ] = NUL;
 
-            pBaseCtx->pzData = parseInput( pzText, textLen );
+            pBaseCtx->pzData = parseInput( pzText, (int)textLen );
             AGFREE( pzText );
 
         } else if (strcasecmp( pzCgiMethod, "GET" ) == 0) {
             if (textLen == 0)
                 textLen = strlen( pzCgiQuery );
-            pBaseCtx->pzData = parseInput( pzCgiQuery, textLen );
+            pBaseCtx->pzData = parseInput( pzCgiQuery, (int)textLen );
 
         } else {
             AG_ABEND( aprf( "invalid CGI request method: ``%s''", pzCgiMethod ));
@@ -185,7 +180,6 @@ parseInput( char* pzSrc, int len )
 /*
  * Local Variables:
  * mode: C
- * tab-width: 4
  * c-file-style: "stroustrup"
  * indent-tabs-mode: nil
  * End:
