@@ -1,12 +1,15 @@
 
 /*
- *  $Id: expOutput.c,v 4.8 2006/01/24 23:22:16 bkorb Exp $
+ *  $Id: expOutput.c,v 4.20 2006/09/28 01:26:33 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-27 11:39:43 bkorb"
+ *  Last Committed:    $Date: 2006/09/28 01:26:33 $
  *
  *  This module implements the output file manipulation function
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -67,14 +70,14 @@ removeWriteAccess( int fd )
      *  Set our usage mask to all all the access
      *  bits that do not provide for write access
      */
-#   define USE_MASK ~(S_IWUSR|S_IWGRP|S_IWOTH)
+#   define USE_MASK ((unsigned)(~(S_IWUSR|S_IWGRP|S_IWOTH)))
     fstat( fd, &sbuf );
 
     /*
      *  Mask off the write permission bits, but ensure that
      *  the user read bit is set.
      */
-    sbuf.st_mode = (sbuf.st_mode & USE_MASK) | S_IRUSR;
+    sbuf.st_mode = ((unsigned)sbuf.st_mode & USE_MASK) | S_IRUSR;
     fchmod( fd, sbuf.st_mode & S_IAMB );
 }
 
@@ -103,7 +106,7 @@ addWriteAccess( char* pzFileName )
 /*=gfunc out_delete
  *
  * what: delete current output file
- * doc:  
+ * doc:
  *  Remove the current output file.  Cease processing the template for
  *  the current suffix.  It is an error if there are @code{push}-ed
  *  output files.  Use the @code{(error "0")} scheme function instead.
@@ -156,7 +159,7 @@ ag_scm_out_move( SCM new_file )
  *
  * what:   close current output file
  * exparg: disp, return contents of the file, optional
- * doc:  
+ * doc:
  *  If there has been a @code{push} on the output, then close that
  *  file and go back to the previously open file.  It is an error
  *  if there has not been a @code{push}.  @xref{output controls}.
@@ -174,7 +177,7 @@ ag_scm_out_pop( SCM ret_contents )
         AG_ABEND( "ERROR:  Cannot pop output with no output pushed\n" );
 
     if (AG_SCM_BOOL_P( ret_contents ) && SCM_NFALSEP( ret_contents )) {
-        long pos = ftell( pCurFp->pFile );
+        unsigned long pos = ftell( pCurFp->pFile );
 
         if (pos != 0) {
             char* pz = ag_scribble( pos );
@@ -196,7 +199,7 @@ ag_scm_out_pop( SCM ret_contents )
  *
  * what:   suspend current output file
  * exparg: suspName, A name tag for reactivating
- * doc:  
+ * doc:
  *  If there has been a @code{push} on the output, then set aside the
  *  output descriptor for later reactiviation with @code{(out-resume "xxx")}.
  *  The tag name need not reflect the name of the output file.  In fact,
@@ -234,9 +237,9 @@ ag_scm_out_suspend( SCM suspName )
 
 /*=gfunc out_resume
  *
- * what:   resume current output file
+ * what:   resume suspended output file
  * exparg: suspName, A name tag for reactivating
- * doc:  
+ * doc:
  *  If there has been a suspended output, then make that output descriptor
  *  current again.  That output must have been suspended with the same tag
  *  name given to this routine as its argument.
@@ -266,12 +269,90 @@ ag_scm_out_resume( SCM suspName )
 }
 
 
+/*=gfunc ag_fprintf
+ *
+ * what:  format to autogen stream
+ * general_use:
+ *
+ * exparg: ag-diversion, AutoGen diversion name or number
+ * exparg: format,       formatting string
+ * exparg: format-arg,   list of arguments to formatting string, opt, list
+ *
+ * doc:  Format a string using arguments from the alist.
+ *       Write to a specified AutoGen diversion.
+ *       That may be either a specified suspended output stream
+ *       (@pxref{SCM out-suspend}) or an index into the output stack
+ *       (@pxref{SCM out-push-new}).  @code{(ag-fprintf 0 ...)} is
+ *       equivalent to @code{(emit (sprintf ...))}, and
+ *       @code{(ag-fprintf 1 ...)} sends output to the most recently
+ *       suspended output stream.
+=*/
+SCM
+ag_scm_ag_fprintf( SCM port, SCM fmt, SCM alist )
+{
+    static char const invalid_z[] = "ag-fprintf: 'port' is invalid";
+    int   list_len = scm_ilength( alist );
+    char* pzFmt    = ag_scm2zchars( fmt, zFormat );
+    SCM   res      = run_printf( pzFmt, list_len, alist );
+
+    /*
+     *  If "port" is a string, it must match one of the suspended outputs.
+     *  Otherwise, we'll fall through to the abend.
+     */
+    if (AG_SCM_STRING_P(port)) {
+        int  ix  = 0;
+        tCC* pzName = ag_scm2zchars( port, "resume name" );
+
+        for (; ix < suspendCt; ix++) {
+            if (strcmp( pSuspended[ ix ].pzSuspendName, pzName ) == 0) {
+                tFpStack* pSaveFp = pCurFp;
+                pCurFp = pSuspended[ ix ].pOutDesc;
+                (void) ag_scm_emit( res );
+                pCurFp = pSaveFp;
+                return SCM_UNDEFINED;
+            }
+        }
+    }
+
+    /*
+     *  If "port" is a number, it is an index into the output stack with
+     *  "0" (zero) representing the current output and "1" the last suspended
+     *  output.  If the number is out of range, we'll fall through to the abend.
+     */
+    else if (AG_SCM_NUM_P(port)) do {
+        tFpStack* pSaveFp = pCurFp;
+        unsigned long val = gh_scm2ulong(port);
+
+        for (; val > 0; val--) {
+            pCurFp = pCurFp->pPrev;
+            if (pCurFp == NULL) {
+                pCurFp = pSaveFp;
+                goto fprintf_woops;
+            }
+        }
+
+        (void) ag_scm_emit( res );
+        pCurFp  = pSaveFp;
+        return SCM_UNDEFINED;
+
+    fprintf_woops: ;
+    } while (0);
+
+    /*
+     *  Still here?  We have a bad "port" specification.
+     */
+    AG_ABEND( invalid_z );
+    /* NOTREACHED */
+    return SCM_UNDEFINED;
+}
+
+
 /*=gfunc out_push_add
  *
  * what:   append output to file
  * exparg: file-name, name of the file to append text to
  *
- * doc: 
+ * doc:
  *  Identical to @code{push-new}, except the contents are @strong{not}
  *  purged, but appended to.  @xref{output controls}.
 =*/
@@ -344,33 +425,22 @@ ag_scm_out_push_new( SCM new_file )
         addWriteAccess( pzNewFile );
         p->pFile = fopen( pzNewFile, "a" FOPEN_BINARY_FLAG "+" );
     }
-#   if defined(ENABLE_FMEMOPEN)
-    else if (! HAVE_OPT( NO_FMEMOPEN ))
-#   else
     else
-#   endif
+#if defined(ENABLE_FMEMOPEN)
+    if (! HAVE_OPT( NO_FMEMOPEN ))
+#endif
     {
         /*
          *  IF we do not have fopencookie(3GNU) or funopen(3BSD), then this
          *  block is a pure "else" clause.  If we do have one of those, then
-         *  the block is executed when a file name is not s specified *and*
+         *  the block is executed when a file name is not specified *and*
          *  --no-fmemopen was *not* selected.
          */
-        tSCC* pzTemp = NULL;
+        static char const * pzTemp = NULL;
         int tmpfd;
 
-        if (pzTemp == NULL) {
-            char* pz = getenv( "TEMP" );
-            if (pz == NULL) {
-                pz = getenv( "TMP" );
-                if (pz == NULL)
-                    pz = "/tmp";
-            }
-
-            pzTemp = aprf( "%s/agtmp.XXXXXX", pz );
-            manageAllocatedData((void*)pzTemp);
-            TAGMEM( pzTemp, "Saved temp file template" );
-        }
+        if (pzTemp == NULL)
+            pzTemp = mkstempPat();
 
         AGDUPSTR( pzNewFile, pzTemp, "temp file name" );
         p->flags |= FPF_UNLINK;
@@ -381,19 +451,19 @@ ag_scm_out_push_new( SCM new_file )
         p->pFile  = fopen( pzNewFile, "w" FOPEN_BINARY_FLAG "+" );
         close( tmpfd );
     }
-#   ifdef ENABLE_FMEMOPEN
-    else {
+#if defined(ENABLE_FMEMOPEN)
+    else
+    {
         /*
          *  This block is a pure "else" clause that is only compiled if neither
          *  "fopencookie" nor "funopen" is available in the local C library.
-         *  Otherwise, anonymous output without --no-fmemopen being selected
-         *  will get us here.
+         *  We reach here if --no-fmemopen was *not* on the command line.
          */
         p->pFile  = ag_fmemopen( NULL, 0, "wb+" );
-        pzNewFile = "in-mem buffer";
+        pzNewFile = (char*)"in-mem buffer";
         p->flags |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
     }
-#   endif /* ENABLE_FMEMOPEN */
+#endif /* ENABLE_FMEMOPEN */
 
     if (p->pFile == NULL)
         AG_ABEND( aprf( zCannot, errno, "open for write", pzNewFile,
@@ -533,7 +603,6 @@ ag_scm_out_line( void )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/expOutput.c */
