@@ -2,7 +2,10 @@
 /*
  *  tpParse.c
  *
- *  $Id: tpParse.c,v 4.8 2006/03/25 19:24:49 bkorb Exp $
+ *  $Id: tpParse.c,v 4.11 2006/09/24 02:59:00 bkorb Exp $
+ *
+ * Time-stamp:        "2006-09-23 19:49:23 bkorb"
+ * Last Committed:    $Date: 2006/09/24 02:59:00 $
  *
  *  This module will load a template and return a template structure.
  */
@@ -27,9 +30,9 @@
  *             Boston, MA  02110-1301, USA.
  */
 
+#if defined(DEBUG_ENABLED)
 static int tplNestLevel = 0;
 
-#if defined(DEBUG_ENABLED)
 tSCC zTDef[] = "%-10s (%d) line %d end=%d, strlen=%d\n";
 #endif
 
@@ -52,7 +55,7 @@ nextMacroStart( tCC* pz, tMacro** ppM, tTemplate* pTpl );
 static teFuncType
 whichFunc( tCC** ppzScan )
 {
-    const char*   pzFuncName = *ppzScan;
+    char const*   pzFuncName = *ppzScan;
     int           hi, lo, av;
     tNameType*    pNT;
     int           cmp;
@@ -93,7 +96,7 @@ whichFunc( tCC** ppzScan )
     do  {
         av  = (hi + lo)/2;
         pNT = nameTypeTable + av;
-        cmp = strneqvcmp( pNT->pName, pzFuncName, pNT->cmpLen );
+        cmp = strneqvcmp( pNT->pName, pzFuncName, (int)pNT->cmpLen );
         if (cmp == 0) {
             /*
              *  Make sure we matched to the end of the token.
@@ -281,8 +284,8 @@ parseTemplate( tMacro* pM, tCC** ppzText )
          *  text pointer to after the marker.
          */
         {
-            const char*  pzMacEnd = pzScan;
-            const char*  pz       = pzMark;
+            char const*  pzMacEnd = pzScan;
+            char const*  pz       = pzMark;
 
             for (;;pz++) {
                 pz = strchr( pz, '\n' );
@@ -348,7 +351,7 @@ parseTemplate( tMacro* pM, tCC** ppzText )
                 if (pM->funcCode == FTYP_BOGUS)
                      fprintf( pfTrace, zTUndef, apzFuncNames[ ft ], ft, ln );
                 else {
-                    const char* pz;
+                    char const* pz;
                     if (ft >= FUNC_CT)
                         ft = FTYP_SELECT;
                     pz = (pM->ozText == 0)
@@ -382,7 +385,6 @@ parseTemplate( tMacro* pM, tCC** ppzText )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/tpParse.c */
