@@ -1,12 +1,11 @@
 /*
- *  $Id: gdinit.c,v 4.3 2006/03/31 19:52:11 bkorb Exp $
+ *  $Id: gdinit.c,v 4.6 2006/09/24 02:59:00 bkorb Exp $
  *
  *    getdefs copyright 1999-2006 Bruce Korb
  *
  *  Author:            Bruce Korb <bkorb@gnu.org>
- *  Maintainer:        Bruce Korb <bkorb@gnu.org>
- *  Created:           Sat Dec 1, 2001
- *  Last Modified:     $Date: 2006/03/31 19:52:11 $
+ *  Time-stamp:        "2006-09-23 19:39:48 bkorb"
+ *  Last Modified:     $Date: 2006/09/24 02:59:00 $
  *            by: bkorb
  */
 
@@ -291,7 +290,7 @@ validateOptions( void )
      */
     {
         char zRER[ MAXNAMELEN ];
-        static const char zReErr[] =
+        static char const zReErr[] =
             "Regex error %d (%s):  Cannot compile reg expr:\n\t%s\n";
 
         int rerr = regcomp( &define_re, pzDefPat, REG_EXTENDED | REG_ICASE );
@@ -420,7 +419,6 @@ validateOptions( void )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of getdefs/gdinit.c */
