@@ -2,12 +2,12 @@
 ##  -*- Mode: shell-script -*-
 ## mklibsrc.sh --   make the libopts tear-off library source tarball
 ##
-## Time-stamp:      "2005-10-28 16:19:20 bkorb"
+## Time-stamp:      "2006-09-19 20:39:50 bkorb"
 ## Maintainer:      Bruce Korb <bkorb@gnu.org>
 ## Created:         Aug 20, 2002
 ##              by: bkorb
 ## ---------------------------------------------------------------------
-## $Id: mklibsrc.sh,v 4.16 2005/11/25 19:09:35 bkorb Exp $
+## $Id: mklibsrc.sh,v 4.18 2006/09/24 02:11:16 bkorb Exp $
 ## ---------------------------------------------------------------------
 ## Code:
 
@@ -25,6 +25,7 @@ tag=libopts-${ao_rev}
 cd ${top_builddir}/pkg
 [ ! -d ${tag} ] || rm -rf ${tag}
 mkdir ${tag} ${tag}/compat ${tag}/autoopts ${tag}/m4
+tagd=`pwd`/${tag}
 
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
@@ -33,44 +34,34 @@ mkdir ${tag} ${tag}/compat ${tag}/autoopts ${tag}/m4
 cd ${top_builddir}/autoopts
 files=`fgrep '#include' libopts.c | \
        sed -e 's,"$,,;s,#.*",,' \
-           -e '/HAVE_LIBSNPRINTFV$/d' \
-           -e '/^streqvcmp\.c$/d' \
-           -e '/^compat\/compat\.h$/d' \
-           -e '/^autoopts\.h$/d'`
+           -e '/^compat\/compat\.h$/d' `
+
 for f in libopts.c ${files}
 do
   if test -f ${f}
-  then cp -f ${f} ${top_builddir}/pkg/${tag}/${f}
-  else cp -f ${top_srcdir}/autoopts/${f} ${top_builddir}/pkg/${tag}/${f}
+  then cp -f ${f} ${tagd}/${f}
+  else cp -f ${top_srcdir}/autoopts/${f} ${tagd}/${f}
   fi
 done
 
 cd ${top_srcdir}/autoopts
-cp -f COPYING ${top_builddir}/pkg/${tag}/COPYING.lgpl
-
-sed '/#ifdef AUTOGEN_BUILD/,/#endif.* AUTOGEN_BUILD/d' streqvcmp.c > \
-  ${top_builddir}/pkg/${tag}/streqvcmp.c
-
-sed '/broken printf/,/our own/d
-     /include.*"snprintfv/d
-     /#ifndef AUTOGEN_BUILD/d
-     /#else.* AUTOGEN_BUILD/,/#endif.* AUTOGEN_BUILD/d' autoopts.h > \
-  ${top_builddir}/pkg/${tag}/autoopts.h
+cp -f COPYING ${tagd}/COPYING.lgpl
 
 cd ../compat
-cp compat.h pathfind.c snprintf.c strdup.c ${top_builddir}/pkg/${tag}/compat/.
+cp windows-config.h compat.h pathfind.c snprintf.c strdup.c strchr.c \
+   ${tagd}/compat/.
 
 #
 #  END WORK IN SOURCE DIRECTORY
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 
-cd ${top_builddir}/pkg/${tag}
+cd ${tagd}
 
 cp ${top_srcdir}/config/libopts*.m4 m4/.
 chmod u+w m4/libopts.m4
 cat ${top_srcdir}/pkg/libopts/libopts-add.m4 >> m4/libopts.m4
-test -f Makefile.am && rm -f Makefile.am
+test ! -f Makefile.am || rm -f Makefile.am
 
 sed s,'\${tag}',"${tag}",g ${top_srcdir}/pkg/libopts/README > README
 cp ${top_srcdir}/pkg/libopts/COPYING* .
@@ -79,14 +70,18 @@ touch MakeDefs.inc
 
 vers=${AO_CURRENT}:${AO_REVISION}:${AO_AGE}
 exec 3> Makefile.am
-cat >&3 <<-	EOMakefile
+cat >&3 <<- EOMakefile
 	## LIBOPTS Makefile
-	MAINTAINERCLEANFILES  = Makefile.in
-	lib_LTLIBRARIES       = libopts.la
-	libopts_la_SOURCES    = libopts.c
-	libopts_la_CPPFLAGS   = -I\$(top_srcdir)
-	libopts_la_LDFLAGS    = -version-info ${AM_LDFLAGS} ${vers}
-	EXTRA_DIST            = \\
+	MAINTAINERCLEANFILES    = Makefile.in
+	if INSTALL_LIBOPTS
+	lib_LTLIBRARIES         = libopts.la
+	else
+	noinst_LTLIBRARIES      = libopts.la
+	endif
+	libopts_la_SOURCES      = libopts.c
+	libopts_la_CPPFLAGS     = -I\$(top_srcdir)
+	libopts_la_LDFLAGS      = -version-info ${AM_LDFLAGS} ${vers}
+	EXTRA_DIST              = \\
 	EOMakefile
 
 find * -type f \
@@ -111,7 +106,6 @@ rm -rf ${tag}
 
 ## Local Variables:
 ## Mode: shell-script
-## tab-width: 4
 ## indent-tabs-mode: nil
 ## sh-indentation: 2
 ## sh-basic-offset: 2
